<?php
/*
Plugin Name: Image Compressor
Plugin URI: http://example.com
Description: A plugin to compress images by 80% and increase quality.
Version: 1.0
Author: Your Name
Author URI: http://example.com
License: GPL2
*/

// Hook into the image upload process
add_filter('wp_handle_upload_prefilter', 'image_compressor_upload_filter');
add_filter('wp_handle_upload', 'image_compressor_handle_upload', 10, 2);

function image_compressor_upload_filter($file) {
    // Check if the uploaded file is an image
    $image_types = ['image/jpeg', 'image/png', 'image/gif'];
    if (in_array($file['type'], $image_types)) {
        // Optionally, you can log or debug the uploaded file
    }
    return $file;
}

function image_compressor_handle_upload($uploaded_file, $context) {
    $file_path = $uploaded_file['file'];
    $file_type = $uploaded_file['type'];

    if ($file_type == 'image/jpeg' || $file_type == 'image/png') {
        // Call a function to compress the image
        $compressed_image = compress_image($file_path, $file_type);

        // Replace the original file with the compressed one
        if ($compressed_image) {
            $uploaded_file['file'] = $compressed_image;
        }
    }
    return $uploaded_file;
}

function compress_image($file_path, $file_type) {
    // Set quality levels
    $quality = 80; // 80% compression

    // Check if ImageMagick or GD is available
    if (extension_loaded('imagick')) {
        // Use ImageMagick for better quality
        $imagick = new Imagick($file_path);
        $imagick->setImageCompressionQuality($quality);
        $imagick->stripImage();  // Remove metadata
        $compressed_path = str_replace('.jpg', '-compressed.jpg', $file_path);
        $imagick->writeImage($compressed_path);
        $imagick->clear();
        return $compressed_path;
    } else {
        // Fallback to GD library if ImageMagick is not available
        return compress_image_gd($file_path, $file_type, $quality);
    }
}

function compress_image_gd($file_path, $file_type, $quality) {
    $image = null;
    if ($file_type == 'image/jpeg') {
        $image = imagecreatefromjpeg($file_path);
    } elseif ($file_type == 'image/png') {
        $image = imagecreatefrompng($file_path);
        imagepalettetotruecolor($image);
        imagealphablending($image, true);
        imagesavealpha($image, true);
    }

    if ($image) {
        // Compress the image
        $compressed_path = str_replace('.jpg', '-compressed.jpg', $file_path);
        imagejpeg($image, $compressed_path, $quality);
        imagedestroy($image);
        return $compressed_path;
    }
    return false;
}

// Add plugin options page for configuring settings if needed
function image_compressor_settings_page() {
    // Options form (for example, to change compression quality)
}

// Add actions for the settings page
add_action('admin_menu', 'image_compressor_settings_page');
